@@ -80,10 +80,7 @@ class Attachment(AttachmentBase):
             # If filename is None at this point, use long filename as first
             # preference.
             if not filename:
-                filename = self.longFilename
-            # Otherwise use the short filename.
-            if not filename:
-                filename = self.shortFilename
+                filename = self.name
             # Otherwise just make something up!
             if not filename:
                 return self.randomFilename
@@ -123,6 +120,10 @@ class Attachment(AttachmentBase):
         either pass a path to where you want to create one or pass an instance
         to :param zip:. If :param zip: is an instance, :param customPath: will
         refer to a location inside the zip file.
+
+        :param extractEmbedded: If true, causes the attachment, should it be an
+            embedded MSG file, to save as a .msg file instead of calling it's
+            save function.
         """
         # First check if we are skipping embedded messages and stop
         # *immediately* if we are.
@@ -205,7 +206,12 @@ class Attachment(AttachmentBase):
 
             return str(fullFilename)
         else:
-            self.saveEmbededMessage(**kwargs)
+            if kwargs.get('extractEmbedded', False):
+                # TODO
+                with _open(str(fullFilename), mode) as f:
+                    self.data.export(f)
+            else:
+                self.saveEmbededMessage(**kwargs)
 
             # Close the ZipFile if this function created it.
             if _zip and createdZip:
