@@ -311,6 +311,10 @@ class ClientIntentFlag(enum.Enum):
 
 
 
+class Color(enum.IntEnum):
+    RED = 0
+    BLACK = 1
+
 
 class ContactAddressIndex(enum.Enum):
     EMAIL_1 = 0
@@ -348,6 +352,15 @@ class DeencapType(enum.Enum):
 
 
 
+class DirectoryEntryType(enum.IntEnum):
+    UNALLOCATED = 0
+    UNKNOWN = 0
+    STORAGE = 1
+    STREAM = 2
+    ROOT_STORAGE = 5
+
+
+
 class DisplayType(enum.Enum):
     MAILUSER = 0x0000
     DISTLIST = 0x0001
